@@ -14,12 +14,14 @@ from pika import (BlockingConnection, BasicProperties, ConnectionParameters,
 from pika.adapters.blocking_connection import BlockingChannel
 from pika.exceptions import (AMQPChannelError, ChannelClosed,
                              AMQPConnectionError)
+from pika import exceptions as e
 from pika.exchange_type import ExchangeType
 from pika.frame import Method
 from pika.spec import Basic
 
-__all__ = ('RabbitClient', 'BasicProperties')
+__all__ = ('RabbitClient', 'BasicProperties', 'exceptions')
 log = logging.getLogger('snacks')
+exceptions = e
 
 
 # TODO django_rest_framework serializer support?
@@ -395,7 +397,7 @@ class RabbitClient:
                     channel = connection.channel()
 
                 def consume(q: str) -> None:
-                    _listen(channel, q, fun)
+                    self._listen(channel, q, fun)
                     level = log.debug if q.startswith('amq.gen') else log.info
                     level('[%s] consuming queue [%s]', fun.__name__, q)
 
@@ -440,58 +442,62 @@ class RabbitClient:
         else:
             return body
 
-
-def _listen(channel: BlockingChannel, queue: str, fun: Callable) -> None:
-    sig = signature(fun)
-
-    def callback(
-            ch: BlockingChannel,
-            method: Basic.Deliver,
-            properties: BasicProperties,
-            body: bytes
+    def _listen(
+            self,
+            channel: BlockingChannel,
+            queue: str,
+            fun: Callable
     ) -> None:
-        log.debug('Queue [%s] received [%s]', queue, body)
-        log.debug('Properties [%s]', properties)
-        kwargs: dict[str, Any] = {}
-        for name, param in sig.parameters.items():
-            annotation = param.annotation
-            if name == 'self':
-                kwargs[name] = None
-            elif annotation == BlockingChannel:
-                kwargs[name] = ch
-            elif annotation == method:
-                kwargs[name] = method
-            elif annotation == BasicProperties:
-                kwargs[name] = properties
-            elif 'application/json' in [properties.content_type,
-                                        properties.content_encoding]:
-                kwargs[name] = _deserialize_json(body, annotation)
-            else:
-                kwargs[name] = _deserialize(annotation, body)
-        # noinspection PyBroadException
-        try:
-            resp = fun(**kwargs)
-            if properties.reply_to:
-                if resp is None:
-                    resp = b''
-                ch.basic_publish(
-                    exchange='',
-                    routing_key=properties.reply_to,
-                    properties=BasicProperties(
-                        correlation_id=properties.correlation_id
-                    ),
-                    body=_serialize(resp)
-                )
-                ch.basic_ack(delivery_tag=method.delivery_tag)
-        except Exception as e:
-            log.exception(msg=f'{type(e).__name__}:{e}', exc_info=e)
+        sig = signature(fun)
 
-    channel.basic_qos(prefetch_count=1)
-    channel.basic_consume(
-        queue=queue,
-        auto_ack=not sig.return_annotation,
-        on_message_callback=callback
-    )
+        def callback(
+                ch: BlockingChannel,
+                method: Basic.Deliver,
+                properties: BasicProperties,
+                body: bytes
+        ) -> None:
+            log.debug('Queue [%s] received [%s]', queue, body)
+            log.debug('Properties [%s]', properties)
+            kwargs: dict[str, Any] = {}
+            for name, param in sig.parameters.items():
+                annotation = param.annotation
+                if name == 'self':
+                    kwargs[name] = None
+                elif annotation == BlockingChannel:
+                    kwargs[name] = ch
+                elif annotation == method:
+                    kwargs[name] = method
+                elif annotation == BasicProperties:
+                    kwargs[name] = properties
+                elif 'application/json' in [properties.content_type,
+                                            properties.content_encoding]:
+                    kwargs[name] = _deserialize_json(body, annotation)
+                else:
+                    kwargs[name] = _deserialize(annotation, body)
+            # noinspection PyBroadException
+            try:
+                resp = fun(**kwargs)
+                if properties.reply_to:
+                    if resp is None:
+                        resp = b''
+                    ch.basic_publish(
+                        exchange='',
+                        routing_key=properties.reply_to,
+                        properties=BasicProperties(
+                            correlation_id=properties.correlation_id
+                        ),
+                        body=self._serialize(resp)
+                    )
+                    ch.basic_ack(delivery_tag=method.delivery_tag)
+            except Exception as e:
+                log.exception(msg=f'{type(e).__name__}:{e}', exc_info=e)
+
+        channel.basic_qos(prefetch_count=1)
+        channel.basic_consume(
+            queue=queue,
+            auto_ack=not sig.return_annotation,
+            on_message_callback=callback
+        )
 
 
 def _deserialize(annotation: Type, body: bytes) -> Any:
